@@ -1,24 +1,11 @@
-if ENV['COVERAGE'] == 'true'
+if RUBY_ENGINE == 'ruby' && RUBY_VERSION >= '3.0'
   require 'simplecov'
-  require 'coveralls'
-
-  SimpleCov.formatter = SimpleCov::Formatter::MultiFormatter[
-    SimpleCov::Formatter::HTMLFormatter,
-    Coveralls::SimpleCov::Formatter
-  ]
-
-  SimpleCov.start do
-    command_name     'spec:unit'
-    add_filter       'config/'
-    add_filter       'spec'
-    add_filter       '.bundle'
-  end
+  SimpleCov.start
 end
 
 require 'rspec'
 require 'bogus/rspec'
 require 'virtus'
-require 'inflecto' # for resolving namespaced constant names
 
 module Virtus
   def self.warn(*)
@@ -32,7 +19,6 @@ ENV['TZ'] = 'UTC'
 Dir[File.expand_path('../shared/**/*.rb', __FILE__)].each { |file| require file }
 
 RSpec.configure do |config|
-
   # Remove anonymous- and example- Attribute classes from Attribute descendants
   config.after :all do
     stack = [ Virtus::Attribute ]
@@ -52,5 +38,4 @@ RSpec.configure do |config|
       end
     end
   end
-
 end
